@@ -21,12 +21,11 @@ use Term::ANSIColor;
 # For test only during dev
 #use Dependencies::Searcher;
 
-our $VERSION = '0.066_004';
+our $VERSION = '0.066_005';
 
 =head1 NAME
 
-Dependencies::Searcher - Search for modules used or required by a
-distribution.
+Dependencies::Searcher - Search for modules used by a distribution.
 
 =cut
 
@@ -50,7 +49,7 @@ distribution.
     # requires Module::Version;
     # ...
 
-    Synopsis from Dependencies::Searcher::AckRequester
+   Synopsis from Dependencies::Searcher::AckRequester
 
     # Places to search...
     my @path = ("./lib", "./Makefile.PL", "./script");
@@ -72,44 +71,34 @@ distribution.
 =head1 DESCRIPTION
 
 Maybe you don't want to have to list all the dependencies of your Perl
-application by hand and want an automated way to build it. Maybe you
-forgot to do it for a long time ago. Or just during a short period.
-Anyway, you've add lots of CPAN modules. L<Carton|Carton> is here to help you
-manage dependencies between your development environment and
-production, but how to keep track of the list of modules you will pass
-to L<Carton|Carton>?
+application by hand and want an automated way to retrieve this
+list. It can also be handy sometimes to check if your Makefile.PL
+contains all the prerequisite that are needed for your distribution. 
 
-Even if it is a no brainer to keep track of this list by adding it by
-hand, it can be much better not to have to do it.
+This module's aim is to keep track of the list of modules your
+distribution need, under the form of a L<cpanfile|cpanfile>.
 
-You will need a tool that will check for any I<requires> or I<use> in
-your module package, and report it into a file that could be used as an
-input L<Carton|Carton> cpanfile. Any duplicated entry will be removed and
-modules versions will be checked and made available. Core modules will be
-ommited because you don't need to install them (except in some special
-case, see C<dissociate()> documentation).
+Dependencies::Searcher will check for any I<requires> or I<use> in
+your module repository, and report it into a cpanfile. Any duplicated
+entry will be removed and modules versions will be checked and made
+available. Core modules will be ommited because you don't need to
+install them (except in some special cases, see C<dissociate()>
+documentation).  
 
-This project has begun because it has happened to me, and I don't want
-to search for modules to install by hand, I just want to run a simple
-script that update the list in a convenient way. It was much more
-longer to write the module than to search by hand so I wish it could
-be useful for you now.
-
-This module is made to search dependencies for I<installed
-distributions>, it is not supposed to manage anything else.
+This project has begun because I was sometimes forgetting to keep
+track of my dependencies, and I just wanted to run a simple script
+that updated the list in a convenient way.
 
 =cut
 
-=head1 WHY ISN'T IT JUST ANOTHER MODULE::SCANDEPS ?
+=head1 Not a dependencies-tree tool
 
-Module::ScanDeps is a bi-dimentional recursive scanner: it features
-dependencies and directories recursivity.
+Dependencies::Searcher only finds direct dependencies, not
+dependencies of dependencies, it scans recursively directories of your
+module to find declared dependencies.
 
-Dependencies::Searcher only found direct dependencies, not
-dependencies of dependencies, it scans recursively directories but not
-dependencies..
-
-These direct dependencies are passed to the Perl toolchain (cpanminus)
+Once you generated a cpanfile with Dependencies::Searcher, it's
+possible to pass this list to the Perl toolchain (cpanminus)
 that will take care of any recursive dependencies.
 
 =cut
@@ -747,21 +736,7 @@ Stupid DIY logger
 
 =head1 CAVEATS
 
-=head2 Low Win32 / Cygwin support
-
-This module was'nt supposed to run under Win32 / Cygwin environments
-because it was using non portable code with slashes. I hope this gets
-better since it has been rewritten using L<Path::Class|Path::Class>
-but it still need some testing.
-
-It also us-e Ack as a hack through a system command even if it was not
-supposed to be used like that. Yes, this is dirty. Yes, I plan to change
-things, even if Ack do the stuff proudly this way.
-
-Thanks to cpantesters.org community reports, things should go better and
-better.
-
-=head2 Fun : some are able to do it using a one-liner
+=head2 Some are able to do it using a one-liner (fun))
 
 Command Line Magic (@climagic) tweeted 4:17 PM on lun., nov. 25, 2013
 
@@ -774,24 +749,23 @@ Though, it don't really work, that's why I made this module.
 
 =cut
 
-=head1 BUGS
+=head1 SOURCE CODE
 
-Please report any bugs or feature requests to
-C<bug-dependencies-searcher at  rt.cpan.org>, or through the web
+L<https://git.framasoft.org/smonff/dependencies-searcher>
+
+=head1 BUGS, ISSUES, TODOs
+
+The simpliest way report any bugs or feature requests is to use Gitlab:
+
+    https://git.framasoft.org/smonff/dependencies-searcher/issues 
+
+If your prefer, you can use the very perlish way and send a mail to  
+C<bug-dependencies-searcher at  rt.cpan.org>, or using the web
 interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dependencies-Searcher>.
 I will be notified, and then you'll automatically be notified of
 progress on your bug as I make changes.
 
-=head1 REPOSITORY
-
-L<https://git.framasoft.org/smonff/dependencies-searcher>
-
-=head1 TODOs
-
-Most of the time, todos and features are on Github and Questub.
-See https://github.com/smonff/dependencies-searcher/issues
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -824,13 +798,13 @@ L<http://search.cpan.org/dist/Dependencies-Searcher/>
 
 =head1 AUTHOR
 
-smonff, C<< <smonff at gmail.com> >>
+smonff, C<< <smonff at riseup.net> >>
 
 =head1 CONTRIBUTORS
 
 =over
 
-=item * Nikolay Mishin (mishin) helps to make it more cross-platform
+=item * Nikolay Mishin (mishin) helped to make it more cross-platform
 
 =item * Alexandr Ciornii (chorny) advises on version numbers
 
@@ -844,8 +818,7 @@ smonff, C<< <smonff at gmail.com> >>
 
 =item L<Module::Extract::Use|Module::Extract::Use>
 
-Was the main inspiration for this one. First, I want to use it for my needs
-but it was not recursive...
+Was the main inspiration for this one. Not recursive though...
 
 See L<https://metacpan.org/module/Module::Extract::Use>
 
@@ -856,21 +829,14 @@ if the module is from Perl Core or not.
 
 See L<http://perldoc.perl.org/Module/CoreList.html>
 
-=item L<http://beyondgrep.com/|Ack>
-
-Ack gives me the wish to try to write this module. It was pure Perl so
-I've choose it because it was possible to install it through CPAN
-during the distribution installation process. Even if Ack was not
-meant for being used programatically, this hacked use of Ack did the
-job during the first part of this module's life. These dready parts
-(use of Ack with IPC::Cmd) have been removed since.
-
 =back
 
 See also :
 
 =over 2
 
+=item * https://metacpan.org/module/Module::ScanDeps
+
 =item * https://metacpan.org/module/Perl::PrereqScanner
 
 =item * http://stackoverflow.com/questions/17771725/
